@@ -2,11 +2,11 @@
 
 __author__ = """Dylan Wootton"""
 __email__ = 'dwootton@mit.edu'
-__version__ = '0.1.24'
+__version__ = '0.1.27'
 
 from .jointplot import *
 from .pairplot import *
 from .distributional import *
 from .relational import *
-from .data_table import *
+from .profile import *
 from .interactions import *
\ No newline at end of file
