@@ -24,9 +24,9 @@ def create_hist_dataframe(data=None, *, x=None, y=None):
   
   return data,x,y
 
-def hist(data=None,x=None,color=None, max_bins=10,width=200,height=50,effects=None,x_axis = alt.Axis(),y_axis=alt.Axis()):
+def hist(data=None,x=None,y=None,color=None, max_bins=10,width=200,height=50,effects=None,x_axis = alt.Axis(),y_axis = alt.Axis() ,x_scale = alt.Scale(), y_scale= alt.Scale()):
   # ensures that data is the data and x and y are column names
-  data,x,y = create_hist_dataframe(data=data,x=x) 
+  data,x,y = create_hist_dataframe(data=data,x=x,y=y) 
 
   fill="steelblue"
 
@@ -38,16 +38,17 @@ def hist(data=None,x=None,color=None, max_bins=10,width=200,height=50,effects=No
 
   if x is not None:
     chart = chart.mark_bar(color=fill).encode(
-            alt.X(f'{x}:Q', bin=alt.Bin(maxbins=max_bins), axis=x_axis),alt.Y('count()',axis=y_axis)
+            alt.X(f'{x}:Q', bin=alt.Bin(maxbins=max_bins),scale=x_scale, axis=x_axis),alt.Y('count()',axis=y_axis)
               ) 
-
-    if color:
+  if y is not None:
+    chart = chart.mark_bar(color=fill).encode(
+            alt.Y(f'{y}:Q', bin=alt.Bin(maxbins=max_bins),scale=y_scale, axis=y_axis),alt.X('count()',axis=x_axis)
+              )
+  if color:
       chart = chart.encode(
         alt.Color(f'{color}:N'), opacity=(alt.value(0.5))
       )
-  else:
-    raise ValueError('[hist] no x value provided')
-
+  
     
   if effects:
     chart = process_effects(chart,effects)
@@ -57,6 +58,46 @@ def hist(data=None,x=None,color=None, max_bins=10,width=200,height=50,effects=No
           height=height
       )
 
+def stripplot(data=None,x=None,row=None,color=None, configure_facet=True, size=None,facet_params={},width=200,height=50,effects=None,y_axis =alt.Axis(values=[0], ticks=True, grid=False, labels=False),x_axis=alt.Axis()):
+ 
+    # dynamically set size of marks based on number of data points
+    if not size and len(data) > 1000:
+      size = 8
+    elif not size and len(data) > 100:
+      size = 40
+    elif not size:
+      size = 90
+    
+
+    chart = alt.Chart(data,width=width,
+          height=height).mark_circle(size=size).encode(
+      y=alt.Y(
+          'jitter:Q',
+          title=None,
+          axis=y_axis,
+          #scale=alt.Scale(),
+      ),
+      x=alt.X(x,axis=x_axis),
+          ).transform_calculate(
+            # Generate Gaussian jitter with a Box-Muller transform
+            jitter='sqrt(-2*log(random()))*cos(2*PI*random())'
+        )                  
+    if color:
+      chart = chart.encode(color=alt.Color(color))
+
+    if row:
+        chart = chart.facet(row=row,**facet_params)
+   
+    if effects:
+      chart = process_effects(chart,effects)
+
+    if configure_facet:
+      chart = chart.configure_facet(
+          spacing=0
+      ).configure_view(
+          stroke=None
+      )
+    return chart
 
 def violin_plot(data=None,y=None,groupby=None, yAxis=None,xAxis=alt.Axis(labels=False, values=[0],grid=False, ticks=True),interactive=False,filters=None):
   if filters is None:
@@ -119,8 +160,9 @@ def violin_plot(data=None,y=None,groupby=None, yAxis=None,xAxis=alt.Axis(labels=
   return final_chart
 
 
-def countplot(data=None,x=None,xAxis=alt.Axis(),yAxis=alt.Axis(),sort='descending', limit=15, effects=None,width=250,height=150):
+def countplot(data=None,x=None,x_axis=alt.Axis(),y_axis=alt.Axis(),sort=None, limit=15, effects=None,width=250,height=150):
   
+ 
 
   if data is None:
     if x is None:
@@ -130,12 +172,15 @@ def countplot(data=None,x=None,xAxis=alt.Axis(),yAxis=alt.Axis(),sort='descendin
       data['x'] = x
       x = 'x'
 
-  # if x 
+  if sort is None:
+    # sort in a descending order, 
+    # the sort must be specified with the columns because otherwise if interaction is present the categorical labels will change their counts. 
+    sort = alt.Sort(data[x].value_counts().index.tolist())
+
 
-  sort_order =  '-y' if sort=='descending' else 'y'
   chart = alt.Chart(data).mark_bar().encode(
-      alt.X(field=f'{x}',axis=xAxis,sort=sort_order), # remove the sort as that will keep it consistent with the background
-      alt.Y(f'count({x}):Q',axis=yAxis)
+      alt.X(field=f'{x}',axis=x_axis,sort=sort), # remove the sort as that will keep it consistent with the background
+      alt.Y(f'count({x}):Q',axis=y_axis)
   )
    
   if effects:
@@ -147,7 +192,6 @@ def countplot(data=None,x=None,xAxis=alt.Axis(),yAxis=alt.Axis(),sort='descendin
           height=height
       )
 
-
 def heatmap(data=None):
   if data is None:
     raise ValueError('[heatmap] no data or data series provided.')
