@@ -47,7 +47,8 @@ ALX_SELECTION_SUFFIX= {
     "filter":"_FILTER",
     "scale_bind":"_FILTER",
     "highlight":"_FILTER",
-    "group":"_GROUP"
+    "group":"_GROUP",
+    "label":"_FILTER" # often used as a part of a filtering operation
 }
 
 def check_if_unit_line(chart):
@@ -71,21 +72,24 @@ def check_if_line(chart):
                 return True
     return False
 
+def is_encoding_meaningful(chart,encoding):
+    encoding_is_aggregate = check_axis_aggregate(chart,encoding) 
+    encoding_field = get_field_from_encoding(chart,encoding)
 
+    RESERVED_ALX_NAMES = ['level','jitter']
+
+    field_is_calculated = encoding_field and any(s in encoding_field for s in RESERVED_ALX_NAMES)
+
+    return not encoding_is_aggregate and not field_is_calculated
 def create_selection(chart,interaction):
     selection = None
     # only allow selection on an axis if it is meaningful (ie data encoded, not 'count')
     # check if any axis is aggregate
     
     if interaction.action['trigger'] == "drag":
-        x_is_aggregate = check_axis_aggregate(chart,'x') 
-        y_is_aggregate = check_axis_aggregate(chart,'y')
-            
-        x_field = get_field_from_encoding(chart,'x')
-        y_field = get_field_from_encoding(chart,'y')
-
-        x_is_meaningful = x_field and 'level' not in x_field and not x_is_aggregate
-        y_is_meaningful = y_field and 'level' not in y_field and not y_is_aggregate
+        x_is_meaningful = is_encoding_meaningful(chart,'x')
+        y_is_meaningful = is_encoding_meaningful(chart,'y')
+        
 
         encodings =  [] # by default
         if x_is_meaningful :
@@ -109,8 +113,13 @@ def create_selection(chart,interaction):
         selection = alt.selection_point(name=name)
         
         if 'target' in interaction.action:
-            field = get_field_from_encoding(chart,interaction.action['target'])
-            selection=alt.selection_point(name=name, encodings=[interaction.action['target']], fields=[field])
+            # if target is a column, then use that as the field
+            if interaction.action['target'] in chart.data.columns:
+                selection=alt.selection_point(name=name,empty=True)
+            else:
+                field = get_field_from_encoding(chart,interaction.action['target'])
+                selection=alt.selection_point(name=name, encodings=[interaction.action['target']], fields=[field])
+            
         else: 
             x_is_aggregate = check_axis_aggregate(chart,'x') 
             y_is_aggregate = check_axis_aggregate(chart,'y')
@@ -121,9 +130,9 @@ def create_selection(chart,interaction):
             
             x_field = get_field_from_encoding(chart,'x')
             y_field = get_field_from_encoding(chart,'y')
-
-            x_is_meaningful = x_field and 'level' not in x_field and not x_is_aggregate
-            y_is_meaningful = y_field and 'level' not in y_field and not y_is_aggregate
+            RESERVED_ALX_NAMES = ['level','jitter']
+            x_is_meaningful = x_field and not any(x_field in s for s in RESERVED_ALX_NAMES) and not x_is_aggregate
+            y_is_meaningful = y_field and not any(y_field in s for s in RESERVED_ALX_NAMES) and not y_is_aggregate
             
             if  x_is_meaningful and not y_is_meaningful:
                 fields.append(x_field)
@@ -137,6 +146,16 @@ def create_selection(chart,interaction):
             elif not x_is_meaningful and not x_is_meaningful:
                 selection=alt.selection_point(name=name, encodings=['x','y'],fields=fields)
 
+    if interaction.action['trigger'] == "slider":
+        name = ALX_SELECTION_PREFIX+'slider'+ALX_SELECTION_SUFFIX[interaction.effect['transform']]
+        field = interaction.action['target']
+        max = chart.data[field].max()
+        min = chart.data[field].min()
+        step = chart.data[field].diff().dropna().unique()[0] or 1
+        slider = alt.binding_range(min=min,max=max,step=step, name=f'{interaction.action["target"]}:')
+        selection = alt.selection_point(name=name, value=min,fields=[interaction.action['target']],
+                                        bind=slider)
+
     if interaction.action['trigger'] == "type":
         name = ALX_SELECTION_PREFIX+'query'+ALX_SELECTION_SUFFIX[interaction.effect['transform']]
 
@@ -162,7 +181,6 @@ def create_selection(chart,interaction):
             params['nearest'] = True
 
         selection = alt.selection_point(**params)
-
     return selection 
 
 def add_colors(chart,data,field,legend=alt.Legend()):
@@ -183,7 +201,6 @@ def add_colors(chart,data,field,legend=alt.Legend()):
 def apply_effect(chart,interaction,selection):
     attributes_for_recursion = ['layer','hconcat','vconcat']
 
-
     for attribute in attributes_for_recursion:
         if alt_get(chart,attribute):
 
@@ -205,13 +222,17 @@ def add_tooltip_chart(chart,interaction,selection):
     if interaction.action['trigger'] == "mouseover":
         
         def add_tooltip_to_mark(chart):
-            tooltip = {"content": "data"}
-            
-            if isinstance(chart.mark,str):
-                mark_type = chart.mark
-                chart.mark = alt.MarkDef(type=mark_type,tooltip=tooltip)
-            else: 
-                chart.mark.tooltip = tooltip
+            if getattr(chart,'mark',None):
+                tooltip = {"content": "data"}
+
+                if getattr(interaction.effect,'target',None):
+                    tooltip['field'] = interaction.effect.target
+                
+                if isinstance(chart.mark,str):
+                    mark_type = chart.mark
+                    chart.mark = alt.MarkDef(type=mark_type,tooltip=tooltip)
+                else: 
+                    chart.mark.tooltip = tooltip
             
             return chart
 
@@ -231,6 +252,11 @@ def apply_effect_recurse(previous_chart,interaction,selection):
         copied_chart.data = chart.data
         
         chart.spec = apply_effect_recurse(copied_chart,interaction,selection)
+        # if there is a dataset already in existance, use that
+        if chart.spec.data is not None and chart.data is not None :
+            
+            chart.spec.data = alt.Undefined
+
         return chart
 
     
@@ -238,7 +264,9 @@ def apply_effect_recurse(previous_chart,interaction,selection):
          chart = filter_chart(chart,interaction,selection)
                 
         # if no encodings exist, 
-    
+    if interaction.effect['transform'] == "label":
+        chart = label_chart(chart,interaction,selection)
+
     if interaction.effect['transform'] == "highlight":
         chart = highlight_chart(chart,interaction,selection)
     if interaction.effect['transform'] == "group":
@@ -252,6 +280,20 @@ def apply_effect_recurse(previous_chart,interaction,selection):
         
     return chart
 
+def label_chart(chart,interaction,selection):
+    x_field = get_field_from_encoding(chart,'x')
+    y_field =  get_field_from_encoding(chart,'y')
+
+    labels = alt.Chart(chart.data).mark_text(align='left',baseline='middle',dx=5,dy=-5).encode(alt.Text('Name'),
+            alt.X(x_field),
+            alt.Y(y_field),
+        ).transform_filter(selection)
+    
+    chart = chart + labels
+    return chart
+    
+   
+
 
 
 def group_chart(chart,interaction,selection):
@@ -369,7 +411,7 @@ def group_chart(chart,interaction,selection):
     return chart
     
     
-    
+# for binding based interactions, you have to use transforms directly as the interaction is not a selection
     
 def filter_chart(chart,interaction,selection):
     filter_transform = alt.FilterTransform({"param": selection.name})
@@ -389,16 +431,20 @@ def filter_chart(chart,interaction,selection):
         
     # for each encoding in selection 
     selection_type = getattr(selection.param,'select',{})
-    encodings = getattr(selection_type,'encodings',None) or ["x","y"] # default to x and y to maintain reference of chart
+    encodings_from_interaction = getattr(selection_type,'encodings',None)
+    change_scale = getattr(interaction.effect,"target","datum") == "extent" # if target is called out, use that. Otherwise target the data elements
+    encodings = encodings_from_interaction if (encodings_from_interaction and not is_undefined(encodings_from_interaction)) else ["x","y"] # default to x and y to maintain reference of chart
     
     # if the interaction occurs via a widget, then axis should be altered
-    interaction_occurs_on_chart = not interaction.action['trigger'] == "type"
+    interaction_occurs_on_chart = not interaction.action['trigger'] == "type" and not change_scale
+
+    # 
+   
 
     # fix the encoding scales so that the view remains static 
     if encodings and not is_undefined(encodings) and interaction_occurs_on_chart: 
         for encoding in encodings:
             field = get_field_from_encoding(chart,encoding)
-            
             if not is_undefined(chart.data) and field and field in chart.data.columns:
                 extent = extent_from_column(chart.data,field)
                 # TODO: copy the existing scale, just overwrite the domain
@@ -494,7 +540,25 @@ def highlight_chart(chart,interaction,selection):
     return chart 
 
 
+class Interactions: 
+    def __init__(self,interactions):
+        self.interactions = interactions
 
+    def __add__(self, other):
+        if isinstance(other,alt.TopLevelSpec):
+            chart = other
+            for interaction in self.interactions:
+                chart = add_interaction(chart,interaction)
+            return chart
+        #chart 
+        if isinstance(other,Interaction):
+            self.interactions.append(other)
+        elif isinstance(other,Interactions):
+            self.interactions.concat(other.interactions)
+        return self
+        
+        
+    
 class Interaction:
     def __init__(self, effect, action,options=None):
         self.effect = effect
@@ -504,6 +568,10 @@ class Interaction:
 
     def __add__(self, other):
         #chart 
+        if isinstance(other,Interaction):
+            return Interactions([self,other])
+        if isinstance(other,Interactions):
+            return Interactions([self,other.interactions])
         return add_interaction(other,self)
     def __radd__(self, other):
         return self.__add__(other)
@@ -520,6 +588,8 @@ _filter = {"transform":"filter"} # _filter as to avoid overloading python's filt
 group = {"transform":"group"}
 scale_bind = {"transform":"scale_bind"}
 tooltip = {"transform":"tooltip"}
+label = {"transform":"label"}
+extent = {"transform":"filter","target":"extent"}
 
 # Input Actions
 brush = {"trigger":"drag"}
@@ -527,10 +597,14 @@ point = {"trigger":"click"}
 color = {"trigger":"click","target":"color"}
 text = {"trigger":"type"}
 brush = {"trigger":"drag"}
+slider = {"trigger":"slider"}
 #hover = {"trigger":"mouseover"}
 
-def tooltip_hover(nearest=False):
+def tooltip_hover(nearest=False,target=None):
     action = {"trigger":"mouseover"}
+    effect = tooltip
+    if target:
+        effect['target'] = target
     action['nearest'] = nearest
     return Interaction(effect=tooltip,action=action)
 
@@ -543,9 +617,14 @@ def highlight_color():
     return Interaction(effect=highlight,action=color)
 def filter_brush():
     return Interaction(effect=_filter,action=brush)
+
+def extent_brush():
+    return Interaction(effect=_filter,action=brush)
+
 def filter_point():
     return Interaction(effect=_filter,action=point)
 
+
 def group_brush():
     return Interaction(effect=group,action=brush)
 def group_point():
@@ -556,6 +635,18 @@ def group_color():
 def pan_zoom(bind_x=True, bind_y=True):    
     return Interaction(effect=scale_bind,action={"trigger":"panzoom"},options={'bind_x':bind_x,'bind_y':bind_y})
 
+# slider functionality currently very limited, only selects the current value (not a predicate) 
+def filter_slider(field):
+    return Interaction(effect=_filter,action={"trigger":"slider","target":field})
+def highlight_slider(field):
+    return Interaction(effect=highlight,action={"trigger":"slider","target":field})
+
+# label functionality 
+def label_brush(field):
+    return Interaction(effect=label,action={"trigger":"drag","target":field})
+def label_point(field):
+    return Interaction(effect=label,action={"trigger":"click","target":field})
+
 def filter_type(target):
     action = { "trigger": "type", "target": target}
     return Interaction(effect=_filter,action=action)
@@ -579,9 +670,20 @@ def process_effects(chart,effects):
       chart = process_groups(chart,effects['group'])
     elif 'tooltip' in effects:
       chart = process_tooltip(chart,effects['tooltip'])
+    elif 'label' in effects:
+      chart = process_tooltip(chart,effects['tooltip'])
 
     return chart
 
+def process_label(chart,label):
+    if isinstance(tooltip, Interaction):
+        parameter = tooltip.get_selection()
+        if parameter is None:
+            parameter = create_selection(chart,label)
+        chart = apply_effect(chart,label,parameter)
+    
+    return chart
+
 def process_tooltip(chart,tooltip):
     if isinstance(tooltip, Interaction):
         parameter = tooltip.get_selection()
