@@ -24,23 +24,24 @@ def generate_shorthand(input_field,data):
   return f'{input_field}:{data_type}'
 
 
-def barplot(data=None, x=None, y=None,y_axis=alt.Axis(),x_axis=alt.Axis(),color=None,column=None,effects=None,width=200,height=200):
+def barplot(data=None, x=None, y=None,sort=None,y_axis=alt.Axis(),x_axis=alt.Axis(),color=None,column=None,effects=None,width=500,height=200):
   data, x, y = create_dataframe(data=data,x=x,y=y)
 
   params = {}
   facet_params = {}
   if color:
      params['color'] = color
-      
-  #if column:
-  #    facet_params['column'] = column
-  #    params['column'] = column
+
+
+  #if not sort:
+    #sort = alt.EncodingSortField(field=y, op="min")
+
   if column:
     num_facets = len(pd.unique(data[column]))
     width = width / num_facets
 
   chart = alt.Chart(data).mark_bar().encode(
-    alt.X(x,axis=x_axis),
+    alt.X(x,axis=x_axis,sort=sort),
     alt.Y(y,axis=y_axis),
     **params
   ).properties(width=width,height=height)
@@ -57,17 +58,14 @@ def barplot(data=None, x=None, y=None,y_axis=alt.Axis(),x_axis=alt.Axis(),color=
 def lineplot(data=None, x=None, y=None,y_axis=alt.Axis(),x_axis=alt.Axis(),color=None,effects=None,width=200,height=200):
   data, x, y = create_dataframe(data=data,x=x,y=y)
 
-  fill = 'steelblue'
-  
-  chart = alt.Chart(data).mark_line(fill=fill).encode(
+  chart = alt.Chart(data).mark_line().encode(
     alt.X(x, scale=alt.Scale(zero=False),axis=x_axis),
     alt.Y(y, scale=alt.Scale(zero=False),axis=y_axis),
   )
 
   if color:
-    if color not in data.columns:
-        fill = color
-    else:
+    if color  in data.columns:
+  
         chart=chart.encode(alt.Color(field=color,scale=alt.Scale()))
   
   if effects:
@@ -75,6 +73,16 @@ def lineplot(data=None, x=None, y=None,y_axis=alt.Axis(),x_axis=alt.Axis(),color
 
   return chart.properties(width=width,height=height)
 
+def dotplot(data=None,x=None,color=None,effects=None,width=200,height=200):
+  # case where your data needs to be binned and aggregated
+  # case where your data is already binned and you have a column for aggregated column
+
+
+
+  if effects:
+    chart = process_effects(chart,effects)
+
+  return chart
 def kdeplot(data=None,x=None,color=None,effects=None,width=200,height=200):
   x_shorthand = generate_shorthand(x,data)
 
@@ -102,19 +110,19 @@ def kdeplot(data=None,x=None,color=None,effects=None,width=200,height=200):
 
   return chart
 
-def scatterplot(data=None, *, x=None, y=None,xAxis=alt.Axis(),color=None,yAxis=alt.Axis(),effects=None,fill="steelblue",width=200,height=200):
+def scatterplot(data=None, *, x=None, y=None,size=None,x_axis=alt.Axis(),color=None,y_axis=alt.Axis(),effects=None,fill="steelblue",width=200,height=200):
 
   data, x, y = create_dataframe(data=data,x=x,y=y)
 
-  x_type = data_type_converter(data.dtypes[x])
-  y_type = data_type_converter(data.dtypes[y])
-
   
   chart = alt.Chart(data).mark_circle().encode(
-      alt.X(shorthand=f'{x}:{x_type}', scale=alt.Scale(zero=False),axis=xAxis),
-      alt.Y(shorthand=f'{y}:{y_type}', scale=alt.Scale(zero=False),axis=yAxis),
+      alt.X(x, scale=alt.Scale(zero=False),axis=x_axis),
+      alt.Y(y, scale=alt.Scale(zero=False),axis=y_axis),
   )
 
+  if size:
+    chart=chart.encode(alt.Size(size))
+
   if color:
     if color not in data.columns:
         chart=chart.mark_circle(fill=color)
