@@ -1,6 +1,6 @@
 import numpy as np
 import pandas as pd
-
+import re
 import altair as alt
 
 def add_encoding(chart,color):
@@ -19,13 +19,21 @@ def is_axis_aggregate(chart,axis):
     AGGREGATION_NAMES = ["count","sum","distinct","missing","mean","average","variance","stdev"]
 
     if encoding:
-        axis_encode = encoding #chart.to_dict()['encoding'].get(axis)
+
+        axis_encode = ''
+        if not is_undefined(encoding.field):
+            axis_encode += encoding.field
+        if not is_undefined(encoding.shorthand):
+            axis_encode += encoding.shorthand
+
+        
         if axis_encode is None:
             return False
         
-        encode_string = f'{axis_encode}'
+
+        encode_string = f'{axis_encode}' 
         for aggregation_name in AGGREGATION_NAMES:
-            if encode_string.find(aggregation_name) > -1:
+            if re.search(r'\b'+aggregation_name+r'\b',encode_string):
                 return True
         return False
     else: 
@@ -37,12 +45,8 @@ def is_axis_binned(chart,axis):
     
     encoding = chart.encoding[axis]
 
-    if encoding:
-        axis_encode = chart.to_dict()['encoding'].get(axis)
-        if axis_encode is None:
-            return False
-        else:
-          return axis_encode.get('bin')
+    if not is_undefined(encoding):
+        return encoding.bin is not None and not is_undefined(encoding.bin)
     else: 
         return False
 
@@ -73,18 +77,21 @@ def recurse_through_units(chart,function,exitOnFirst = False):
                 return result
 def check_axis_binned(chart,axis):
     is_meaningful = is_axis_binned(chart,axis)
-    
-    # if a layered chart, 
-    if alt_get(chart,'layer'):
-        for layer in chart.layer:
-            if is_axis_binned(layer,axis):
-                return True
+
+    attributes_for_recursion = ['layer','spec']
+    for attribute in attributes_for_recursion:
+        if alt_get(chart,attribute):
+            for layer in chart[attribute]:
+                if is_axis_binned(layer,axis):
+                    return True
     return is_meaningful
 
 
 def check_axis_aggregate(chart,axis):
+    """
+    Checks if an axis is aggregate, and if it is, returns True, else False
+    """
     is_aggregate = is_axis_aggregate(chart,axis)
-    
     attributes_for_recursion = ['layer','hconcat','vconcat','spec']
     for attribute in attributes_for_recursion:
         if alt_get(chart,attribute):
